from odoo import api, fields, models


class AccountMoveLine(models.Model):
    _inherit = 'account.move.line'

    is_discount = fields.Boolean(string='Is a Discount?',
                                 compute='_compute_is_discount',
                                 help="Tracks if the Journal Item was applied as an "
                                      "automatic discount (based on a payment term)")

    @api.multi
    @api.depends('move_id', 'move_id.line_ids', 'move_id.line_ids.payment_id', 'move_id.line_ids.payment_id.writeoff_account_id')
    def _compute_is_discount(self):
        """
        Determine if a Journal Item is a discount.

        It is considered a discount if it uses an Account which matches the
        Writeoff Account from any payment related to any other Journal Items
        on the related Journal Entry.

        :return None:
        """
        for line in self:
            line.is_discount = line.account_id in line.move_id.line_ids.mapped('payment_id.writeoff_account_id')
