from odoo import api, models
from odoo.addons.account.models.account_payment import MAP_INVOICE_TYPE_PARTNER_TYPE


class AccountPayment(models.Model):
    """
    Inherit the Payments model to add some automation to the Register Payment
    process (started from an Invoice form's "Register Payment" button).
    """
    _inherit = "account.payment"

    @api.model
    def default_get(self, fields):
        """
        Inherit `super` to modify the default values for the Register Payment
        form. If the invoice is eligible for a discount (based on its
        Payment Terms), default these values:
          - Payment Amount: Amount Due (Discounted)
          - Payment Difference: Mark invoice as fully paid
          - Post Difference in: Default Payment Difference Account for invoice type

        :param list fields: fields for which to get default values
        :return dict: default fields/values for the payment
        """
        rec = super(AccountPayment, self).default_get(fields)
        invoice_defaults = self.resolve_2many_commands('invoice_ids', rec.get('invoice_ids'))
        if invoice_defaults and len(invoice_defaults) == 1:
            invoice = invoice_defaults[0]
            rec['amount'] = invoice['amount_due_discount']
            if invoice['amount_due_discount'] != invoice['residual']:
                # Payment is eligible for a discount. Set writeoff defaults.
                rec['payment_difference_handling'] = 'reconcile'
                partner_type = MAP_INVOICE_TYPE_PARTNER_TYPE.get(invoice['type'])
                writeoff_account_id = self.env['ir.default'].get(
                    model_name='account.payment',
                    field_name='writeoff_account_id',
                    company_id=self.env.user.id,
                    condition=partner_type)
                rec['writeoff_account_id'] = writeoff_account_id and writeoff_account_id[0]
        return rec
