from odoo import api, fields, models


class ResConfigSettings(models.TransientModel):
    _inherit = 'res.config.settings'

    payment_discount_account_customer = fields.Many2one(
        'account.account',
        string='Default Payment Difference Account for Customer Invoices',
        help="When a payment is being registered on a Customer Invoice, this "
             "will be the automatically suggested account.")
    payment_discount_account_supplier = fields.Many2one(
        'account.account',
        string='Default Payment Difference Account for Vendor Bills',
        help="When a payment is being registered on a Vendor Bill, this will "
             "be the automatically suggested account.")

    @api.onchange('company_id')
    def onchange_company_id(self):
        """
        Inherit `super` to load the current Default Payment Difference Accounts,
        if any are already set.

        :return None:
        """
        if self.company_id:
            # Update default payment accounts
            ir_default_obj = self.env['ir.default'].sudo()
            customer_account = ir_default_obj.get(
                model_name='account.payment',
                field_name='payment_discount_account_customer',
                company_id=self.company_id.id or self.env.user.company_id.id)
            supplier_account = ir_default_obj.get(
                model_name='account.payment',
                field_name='payment_discount_account_supplier',
                company_id=self.company_id.id or self.env.user.company_id.id)
            self.payment_discount_account_customer = isinstance(customer_account, list) and customer_account[:1] or customer_account
            self.payment_discount_account_supplier = isinstance(supplier_account, list) and supplier_account[:1] or supplier_account

    @api.multi
    def set_values(self):
        """
        Set the default payment discount accounts if they have changed.

        As of Odoo 11, we are no longer allowed to set for anything other than a
        valid field for the given model. Previously we can set any value we want
        so now we have to work with the given `condition` to be more specific.

        :return None:
        """
        super(ResConfigSettings, self).set_values()
        ir_default_obj = self.env['ir.default'].sudo()
        if self.payment_discount_account_customer:
            ir_default_obj.set(
                model_name='account.payment',
                field_name='writeoff_account_id',
                value=self.payment_discount_account_customer.ids,
                company_id=self.company_id.id,
                condition="customer")
        if self.payment_discount_account_supplier:
            ir_default_obj.set(
                model_name='account.payment',
                field_name='writeoff_account_id',
                value=self.payment_discount_account_supplier.ids,
                company_id=self.company_id.id,
                condition="supplier")
